Builder
-------

Model builder
=============
.. automodule:: gordo.builder.build_model
    :members:
    :undoc-members:
    :show-inheritance:


Local Model builder
===================

This is meant to provide a good way to validate a configuration file
as well as to enable creating and testing models locally with little overhead.

.. automodule:: gordo.builder.local_build
    :members:
    :undoc-members:
    :show-inheritance:

